OC.L10N.register(
    "files_odfviewer",
    {
    "Close" : "Mbylle"
},
"nplurals=2; plural=(n != 1);");
